==> vue-cli-plugin-package-1.0.1.tgz: package/index.js <==
/*
 * @Author: 文贝
 * @Date: 2022-08-30 21:13:13
 * @LastEditors: 文贝
 * @LastEditTime: 2022-10-19 17:36:33
 * @Descripttion:
 * @FilePath: \vue-cli-plugin-package\index.js
 */
const path = require("path");
const Package = require("@icreate/package");
const { createDBMigrate, DBType } = require("@icreate/ics-db-migrate");
const semver = require("semver");
const defaults = {
  clean: true,
  target: "app",
  formats: "commonjs,umd,umd-min",
  "unsafe-inline": true,
};

module.exports = (api, options) => {
  const rootPath = path.resolve("");
  api.registerCommand(
    "build:package",
    {
      description: "build for production",
      usage: "vue-cli-service build:package [options] [entry|pattern]",
      options: {
        "--mode": `specify env mode (default: production)`,
        "--dest": `specify output directory (default: ${options.outputDir})`,
        "--modern": `build app targeting modern browsers with auto fallback`,
        "--no-unsafe-inline": `build app without introducing inline scripts`,
        "--target": `app | lib | wc | wc-async (default: ${defaults.target})`,
        "--inline-vue":
          "include the Vue module in the final bundle of library or web component target",
        "--formats": `list of output formats for library builds (default: ${defaults.formats})`,
        "--name": `name for lib or web-component mode (default: "name" in package.json or entry filename)`,
        "--filename": `file name for output, only usable for 'lib' target (default: value of --name)`,
        "--no-clean": `do not remove the dist directory before building the project`,
        "--report": `generate report.html to help analyze bundle content`,
        "--report-json": "generate report.json to help analyze bundle content",
        "--skip-plugins": `comma-separated list of plugin names to skip for this run`,
        "--watch": `watch for changes`,
        "--stdin": `close when stdin ends`,
      },
    },
    async (args) => {
      // 排除依赖
      if (!args.main) {
        api.chainWebpack((config) => {
          config.set("externals", {
            vue: "Vue",
            vuex: "Vuex",
            "vue-router": "VueRouter",
            "@icreate/core": "IcsCore",
            "@icreate/ics-chromely-plugin-core": "IcsChromelyPluginCore",
            "@/utils/hb-request": "HBRequest",
            "@/utils/imedx-server": "ImedxService",
            "@/utils/request": "IcsRequest",
            "js-cookie": "JsCookies",
            "@icreate/ics-ui": "IcsUI",
            "@icreate/ics-icon":"IcsIcon",
            "@icreate/ics-utils":"IcsUtils", 
            "@icreate/ics-ui/lib/ics-ui.css": "IcsUIcss",
            "element-ui": "ElementUI",
            "element-ui/lib/theme-chalk/index.css": "ElementUICss",
            "normalize.css/normalize.css": "normalize.css",
            "nprogress":"NProgress",
            "nprogress/nprogress.css":"nprogress.css"
          });
        });
      }
      await api.service.run("build", args);
      const pack = new Package();
      const params = {};
      // 处理路由
      const constantRouterMap = [];
      const routersFiles = await pack.requireContext(
        "src/views",
        true,
        /router.js/
      );
      routersFiles.map((router) => {
        constantRouterMap.push(router.module);
      }, {});
      // 解构包信息
      const {
        appId,
        appName,
        appType,
        name,
        title,
        description,
        secret,
        version,
        author,
        createTime,
      } =  require(path.join(rootPath, "package.json"));
      // 解构依赖信息
      const dependencies = require(path.join(rootPath, ".ma.dependency.js"));
      // 解构依赖信息
      const upgrades = require(path.join(rootPath, ".ma.upgrade.js"));
      let forceVersion = "";
      for (const key in upgrades) {
        upgrades[key]["version"] = key;
        if (
          upgrades[key].forced &&
          (!forceVersion || semver.gt(key, forceVersion))
        ) {
          forceVersion = key;
        }
      }

      // 解构客户端参数信息
      params.client = require(path.join(rootPath, ".ma.parameter.client.js"));
      for (const key in params.client) params.client[key]["id"] = key;
      // 解构系统参数信息
      params.system = require(path.join(rootPath, ".ma.parameter.system.js"));
      for (const key in params.system) params.system[key]["id"] = key;
      // 处理权限
      const permissions = pack.permission(constantRouterMap);
      // 应用包信息
      await pack.writeSync(path.join(rootPath, "dist/.package"), {
        appId,
        appName,
        appType,
        id: name,
        name: title,
        description,
        secret,
        version,
        forceVersion,
        author,
        createTime,
        dependencies,
        permissions,
        upgrades,
        params,
      });
      // 生成脚本
      const constantScriptMap = {};
      const scriptFiles = await pack.requireContext("scripts", false, /\.js$/);
      scriptFiles.map((script) => {
        const version = script.name.substring(0, script.name.length - 3);
        constantScriptMap[version] = {};
        // up script
        const upSqlBuilder = createDBMigrate(DBType.Oracle);
        script.module.up(upSqlBuilder);
        constantScriptMap[version]["up"] = upSqlBuilder.text();
        // down script
        const downSqlBuilder = createDBMigrate(DBType.Oracle);
        script.module.down(downSqlBuilder);
        constantScriptMap[version]["down"] = downSqlBuilder.text();
      }, {});
      await pack.writeSync(
        path.join(rootPath, "dist/.script"),
        constantScriptMap
      );
      // 打包字典
      const constantDictionaryMap = [];
      const dictionaryFiles = await pack.requireContext(
        "dictionarys",
        false,
        /\.js$/
      );
      dictionaryFiles.map((dictionary) => {
        if (dictionary.name.substring(0, 13) !== "dict_template") {
          constantDictionaryMap.push(dictionary.module);
        }
      }, {});
      await pack.writeSync(
        path.join(rootPath, "dist/.dictionary"),
        constantDictionaryMap
      );
      // 打包应用
      await pack.packageSync(
        path.join(rootPath, "dist"),
        path.join(rootPath, `../package/${name}.mapkg`)
      );
    }
  );
};

module.exports.defaultModes = {
  "build:package": "production",
};

==> vue-cli-plugin-package-1.0.3.tgz: package/index.js <==
/*
 * @Author: 文贝
 * @Date: 2022-08-30 21:13:13
 * @LastEditors: 陶慧灵
 * @LastEditTime: 2022-11-17 17:35:14
 * @Descripttion:
 * @FilePath: \vue-cli-plugin-package\index.js
 */
const path = require("path");
const Package = require("@icreate/package");
const { createDBMigrate, DBType } = require("@icreate/ics-db-migrate");
const semver = require("semver");
const defaults = {
  clean: true,
  target: "app",
  formats: "commonjs,umd,umd-min",
  "unsafe-inline": true,
};

module.exports = (api, options) => {
  const rootPath = path.resolve("");
  api.registerCommand(
    "build:package",
    {
      description: "build for production",
      usage: "vue-cli-service build:package [options] [entry|pattern]",
      options: {
        "--mode": `specify env mode (default: production)`,
        "--dest": `specify output directory (default: ${options.outputDir})`,
        "--modern": `build app targeting modern browsers with auto fallback`,
        "--no-unsafe-inline": `build app without introducing inline scripts`,
        "--target": `app | lib | wc | wc-async (default: ${defaults.target})`,
        "--inline-vue":
          "include the Vue module in the final bundle of library or web component target",
        "--formats": `list of output formats for library builds (default: ${defaults.formats})`,
        "--name": `name for lib or web-component mode (default: "name" in package.json or entry filename)`,
        "--filename": `file name for output, only usable for 'lib' target (default: value of --name)`,
        "--no-clean": `do not remove the dist directory before building the project`,
        "--report": `generate report.html to help analyze bundle content`,
        "--report-json": "generate report.json to help analyze bundle content",
        "--skip-plugins": `comma-separated list of plugin names to skip for this run`,
        "--watch": `watch for changes`,
        "--stdin": `close when stdin ends`,
      },
    },
    async (args) => {
      // 解构包信息
      const {
        appId,
        appName,
        appType,
        name,
        title,
        description,
        secret,
        version,
        author,
        createTime,
      } = require(path.join(rootPath, "package.json"));
      // 排除依赖
      if (!args.main) {
        api.chainWebpack((config) => {
          let externals = {
            vue: "Vue",
            vuex: "Vuex",
            "vue-router": "VueRouter",
            "@icreate/core": "IcsCore",
            "@icreate/ics-chromely-js-sdk": "IcsChromelyRequest",
            "@icreate/ics-chromely-plugin-core": "IcsChromelyPluginCore",
            "@/utils/hb-request": "HBRequest",
            "@/utils/imedx-server": "ImedxService",
            "@/utils/request": "IcsRequest",
            "./utils/event-bus": "EventBus",
            "@/utils/event-bus": "EventBus",
            "js-cookie": "JsCookies",
            "@icreate/ics-ui": "IcsUI",
            "@icreate/ics-utils": "IcsUtils",
            "@icreate/ics-ui/lib/ics-ui.css": "IcsUIcss",
            "element-ui": "ElementUI",
            "element-ui/lib/theme-chalk/index.css": "ElementUICss",
            "normalize.css/normalize.css": "normalize.css",
            nprogress: "NProgress",
            "nprogress/nprogress.css": "nprogress.css",
          }          
          // 非Icon打包模式
          if(!args.icon) 
            externals["@icreate/ics-icon"] = "IcsIcon";
          config.set("externals", externals);
        });
      }
      // 替换自定义组件打包入口
      if (appType === "component") {
        api.chainWebpack((config) => {
          config.entry('app').clear().add('./src/index.js').end()
        });
      }
      options.css.extract = true;
      await api.service.run("build", args);
      const pack = new Package();
      const params = {};
      // 处理路由
      const constantRouterMap = [];
      const routersFiles = await pack.requireContext(
        "src/views",
        true,
        /router.js/
      );
      routersFiles.map((router) => {
        constantRouterMap.push(router.module);
      }, {});
      // 解构依赖信息
      const dependencies = require(path.join(rootPath, ".ma.dependency.js"));
      // 解构依赖信息
      const upgrades = require(path.join(rootPath, ".ma.upgrade.js"));
      let forceVersion = "";
      for (const key in upgrades) {
        upgrades[key]["version"] = key;
        if (
          upgrades[key].forced &&
          (!forceVersion || semver.gt(key, forceVersion))
        ) {
          forceVersion = key;
        }
      }

      // 解构客户端参数信息
      params.client = require(path.join(rootPath, ".ma.parameter.client.js"));
      for (const key in params.client) params.client[key]["id"] = key;
      // 解构系统参数信息
      params.system = require(path.join(rootPath, ".ma.parameter.system.js"));
      for (const key in params.system) params.system[key]["id"] = key;
      // 处理权限
      const permissions = pack.permission(constantRouterMap);
      // 应用包信息
      await pack.writeSync(path.join(rootPath, "dist/.package"), {
        appId,
        appName,
        appType,
        id: name,
        name: title,
        description,
        secret,
        version,
        forceVersion,
        author,
        createTime,
        dependencies,
        permissions,
        upgrades,
        params,
      });
      // 生成脚本
      const constantScriptMap = {};
      const scriptFiles = await pack.requireContext("scripts", false, /\.js$/);
      scriptFiles.map((script) => {
        const version = script.name.substring(0, script.name.length - 3);
        constantScriptMap[version] = {};
        // up script
        const upSqlBuilder = createDBMigrate(DBType.Oracle);
        script.module.up(upSqlBuilder);
        constantScriptMap[version]["up"] = upSqlBuilder.text();
        // down script
        const downSqlBuilder = createDBMigrate(DBType.Oracle);
        script.module.down(downSqlBuilder);
        constantScriptMap[version]["down"] = downSqlBuilder.text();
      }, {});
      await pack.writeSync(
        path.join(rootPath, "dist/.script"),
        constantScriptMap
      );
      // 打包字典
      const constantDictionaryMap = [];
      const dictionaryFiles = await pack.requireContext(
        "dictionarys",
        false,
        /\.js$/
      );
      dictionaryFiles.map((dictionary) => {
        if (dictionary.name.substring(0, 13) !== "dict_template") {
          constantDictionaryMap.push(dictionary.module);
        }
      }, {});
      await pack.writeSync(
        path.join(rootPath, "dist/.dictionary"),
        constantDictionaryMap
      );
      // 打包应用
      await pack.packageSync(
        path.join(rootPath, "dist"),
        path.join(rootPath, `../package/${name}.mapkg`)
      );
    }
  );
};

module.exports.defaultModes = {
  "build:package": "production",
};
